@@ -1,28 +1,33 @@
-import requests as rq
 from bs4 import BeautifulSoup
+import cloudscraper
 
 class Part:
 
-    def __init__(self,link):
+    def __init__(self,URL):
         try:
-            self.link = 'https://pcpartpicker.com' + str(link)
-            req = rq.get(self.link,headers=rq.utils.default_headers())
-            self.soup = BeautifulSoup(req.text,'html.parser')
-        except:  raise AttributeError
+            self.link = 'https://pcpartpicker.com' + str(URL)
+            scraper = cloudscraper.create_scraper()
+            request = scraper.get(self.link).content
+            self.HTML = BeautifulSoup(request, 'html.parser')
+        except:
+            raise AttributeError
 
     def name(self):
-        try:  return self.soup.find('h1',class_='pageTitle').get_text()
-        except:  return None
+        try:
+            return self.HTML.find('h1',class_='pageTitle').get_text()
+        except:
+            return None
 
     def type(self):
         try:
-            type_string = self.soup.find('section',class_='breadcrumb').find('ol')
+            type_string = self.HTML.find('section',class_='breadcrumb').find('ol')
             return type_string.find('li').find('a').get_text()
-        except:  return None
+        except:
+            return None
 
     def amazon_link(self):
         try:
-            links = self.soup.find_all('a',href=True)
+            links = self.HTML.find_all('a',href=True)
             badlinks = [
             'https://www.facebook.com/pcpartpicker/',
             'https://www.instagram.com/pcpartpicker/',
@@ -34,20 +39,21 @@ class Part:
             'https://cyclingbuilder.com/'
             ]
             for link in links:
-                if link['href'][:6] == 'https:' and link['href'] not in badlinks:
-                    if 'youtube.com' not in link['href']:
-                        if 'amazon.com/tryprimefree' not in link['href']:
+                if link['href'].startswith('https:') and link['href'] not in badlinks:
+                    if 'youtube.com' not in link['href'] and 'amazon.com/tryprimefree' not in link['href']:
                             return link['href']
-        except:  return None
+        except:
+            return None
 
     def price(self):
         try:
-            string = self.soup.find('td',class_='td__finalPrice')
+            string = self.HTML.find('td',class_='td__finalPrice')
             return float(string.find('a').get_text().replace('$','')[:-1])
-        except:  return None
+        except:
+            return None
 
     def advanced_specs(self):
-        groups = self.soup.find_all('div',class_='group group--spec')
+        groups = self.HTML.find_all('div', class_='group group--spec')
         return_dict = {}
         for group in groups:
             head_text = str(group.find('h3').text).replace('\n','')
@@ -60,15 +66,17 @@ class Part:
 
     def rating(self):
         try:
-            rating_html_code = self.soup.find('div',class_="actionBox actionBox__ratings")
-            rating_html = rating_html_code.find('ul').find_all('li')[-1]
-            num = rating_html.get_text().split(',')[1]
+            ratingHTMLraw = self.HTML.find('div',class_="actionBox actionBox__ratings")
+            ratingHTML = ratingHTMLraw.find('ul').find_all('li')[-1]
+            num = ratingHTML.get_text().split(',')[1]
             return float(num.replace(' ','').replace('Average','')[:-1])
-        except:  return None
+        except:
+            return None
 
     def reviews(self,results=1):
-        reviews = self.soup.find_all('div',class_="partReviews__writeup markdown")
-        if results > len(reviews):  results = len(reviews)
+        reviews = self.HTML.find_all('div',class_="partReviews__writeup markdown")
+        if results > len(reviews):
+            results = len(reviews)
         return [x.find('p').text for x in reviews[:results]]
 
 def Query(search_term,results=3,exclude_laptops=False,pages=1):
@@ -84,8 +92,9 @@ def Query(search_term,results=3,exclude_laptops=False,pages=1):
         part_list = []
         for page_n in range(1,pages+1):
             real_url = url + '&page={}'.format(str(page_n))
-            search = rq.get(real_url,headers=rq.utils.default_headers())
-            html = BeautifulSoup(search.text,'html.parser')
+            scraper = cloudscraper.create_scraper()
+            search = scraper.get(real_url).content
+            html = BeautifulSoup(search, 'html.parser')
             search_result = html.find('section', class_="search-results__pageContent")
             search_result_list = search_result.find_all('ul',class_='list-unstyled')
             i = 0
@@ -99,5 +108,3 @@ def Query(search_term,results=3,exclude_laptops=False,pages=1):
     except:
         if len(part_list) > 0:  return part_list
         return None
-
-print(Query('i9 9900k',1,True,1)[0].price())
